@@ -5,32 +5,50 @@ from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 
-__all__ = ['CreateInventoriesStart', 'CreateInventories']
-
 
 class CreateInventoriesStart(ModelView):
     'Create Inventories'
     __name__ = 'stock.inventory.create.start'
     date = fields.Date('Date', required=True)
-    lost_found = fields.Many2One(
-        'stock.location', 'Lost and Found', required=True,
-        domain=[('type', '=', 'lost_found')])
     company = fields.Many2One('company.company', 'Company', required=True,
             select=True)
+    empty_quantity = fields.Selection(
+        'get_empty_quantities', "Empty Quantity",
+        help="How lines without a quantity are handled.")
+    complete_lines = fields.Boolean(
+        "Complete",
+        help="Add an inventory line for each missing product.")
     locations = fields.Many2Many('stock.location', None, None,
             'Locations', required=True, domain=[('type', '=', 'storage')])
 
     @classmethod
-    def default_lost_found(cls):
-        Location = Pool().get('stock.location')
-        locations = Location.search(cls.lost_found.domain)
-        if len(locations) == 1:
-            return locations[0].id
+    def default_date(cls):
+        return Pool().get('ir.date').today()
 
     @staticmethod
     def default_company():
         return Transaction().context.get('company')
 
+    @classmethod
+    def get_empty_quantities(cls):
+        pool = Pool()
+        Inventory = pool.get('stock.inventory')
+        return Inventory.fields_get(
+            ['empty_quantity'])['empty_quantity']['selection']
+
+    @classmethod
+    def default_empty_quantity(cls):
+        pool = Pool()
+        Inventory = pool.get('stock.inventory')
+        try:
+            return Inventory.default_empty_quantity()
+        except AttributeError:
+            return
+
+    @classmethod
+    def default_complete_lines(cls):
+        return True
+
 
 class CreateInventories(Wizard):
     'Create Inventories'
@@ -42,21 +60,24 @@ class CreateInventories(Wizard):
             ])
     create_ = StateAction('stock.act_inventory_form')
 
+    def get_inventory(self, location, Inventory):
+        return Inventory(
+            location=location,
+            date=self.start.date,
+            company=self.start.company,
+            empty_quantity=self.start.empty_quantity)
+
     def do_create_(self, action):
-        Inventory = Pool().get('stock.inventory')
+        pool = Pool()
+        Inventory = pool.get('stock.inventory')
 
-        to_create = []
-        for location in self.start.locations:
-            to_create.append({
-                        'location': location.id,
-                        'date': self.start.date,
-                        'lost_found': self.start.lost_found.id,
-                        'company': self.start.company.id,
-                        })
-        if to_create:
-            inventories = Inventory.create(to_create)
+        inventories = [
+            self.get_inventory(location, Inventory)
+            for location in self.start.locations]
+        Inventory.save(inventories)
 
-        Inventory.complete_lines(inventories)
+        if self.start.complete_lines:
+            Inventory.complete_lines(inventories)
 
         data = {'res_id': [i.id for i in inventories]}
         return action, data
